@@ -23,14 +23,6 @@ load_dotenv(dotenv_path=Path.cwd() / ".env")
 
 LOGGER = logging.getLogger(__name__)
 
-# event names
-EVENT_PRE_SETUP = "pre-setup"
-EVENT_POST_SETUP = "post-setup"
-EVENT_PRE_PROCESS = "pre-process"
-EVENT_POST_PROCESS = "post-process"
-EVENT_PRE_TEARDOWN = "pre-teardown"
-EVENT_POST_TEARDOWN = "post-teardown"
-
 
 class Engine(ABC):
     """Base class for our Engines.
@@ -227,6 +219,7 @@ class EntryPoint:
                 self.reporter.fire(event)
             except Exception:
                 LOGGER.error("Reporter fails to send its status")
+                traceback.print_exc()
 
 
 def create_engine():
