@@ -1,3 +1,4 @@
+from minionize.reporter import NullReporter
 import unittest
 import unittest.mock as mock
 
@@ -19,11 +20,13 @@ class TestEntryPointGeneral(unittest.TestCase):
         callback.setup = mock.Mock()
         callback.process = mock.Mock()
         callback.teardown = mock.Mock()
+
         self.engine = engine
         self.callback = callback
+        self.reporter = NullReporter()
 
     def test_normal_operations(self):
-        entrypoint = EntryPoint(self.callback, self.engine)
+        entrypoint = EntryPoint(self.callback, self.engine, self.reporter)
         entrypoint.run()
 
         self.assertEqual(2, self.engine.next.call_count)
@@ -34,7 +37,7 @@ class TestEntryPointGeneral(unittest.TestCase):
     def test_operations_one_exception(self):
         exception = TestException("test_exception")
         self.callback.process = mock.Mock(side_effect=[exception, None])
-        entrypoint = EntryPoint(self.callback, self.engine)
+        entrypoint = EntryPoint(self.callback, self.engine, self.reporter)
         entrypoint.run()
 
         self.assertEqual(2, self.engine.next.call_count)
@@ -54,9 +57,10 @@ class TestEntryPointWithProcessCallback(unittest.TestCase):
         callback = ProcessCallback()
         self.engine = engine
         self.callback = callback
+        self.reporter = NullReporter()
 
     def test_normal_operations(self):
-        entrypoint = EntryPoint(self.callback, self.engine)
+        entrypoint = EntryPoint(self.callback, self.engine, self.reporter)
         entrypoint.run()
 
         self.assertEqual(2, self.engine.next.call_count)
@@ -69,7 +73,7 @@ class TestEntryPointWithProcessCallback(unittest.TestCase):
             def to_cmd(self, param):
                 return "exit 1"
 
-        entrypoint = EntryPoint(CustomCallback(), self.engine)
+        entrypoint = EntryPoint(CustomCallback(), self.engine, self.reporter)
         entrypoint.run()
 
         self.assertEqual(2, self.engine.next.call_count)
